﻿using System;
using System.Windows;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input.Touch;

namespace P28_2
{
    public partial class GamePage : PhoneApplicationPage
    {
        // Менеджер контента
        ContentManager contentManager;
        // Таймер для организации игрового цикла
        GameTimer timer;
        // Объект для вывода 2D-графики
        SpriteBatch spriteBatch;
        // Текстура для хранения изображения
        private Texture2D mySprite;
        //Позиция вывода изображения
        private Vector2 position = new Vector2(0, 200);

        public GamePage()
        {
            InitializeComponent();

            // Получить диспетчер содержимого из приложения
            contentManager = (Application.Current as App).Content;

            // Создайте таймер для этой страницы
            timer = new GameTimer();
            timer.UpdateInterval = TimeSpan.FromTicks(333333);
            timer.Update += OnUpdate;
            timer.Draw += OnDraw;
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // В графическом устройстве включите визуализацию XNA для режима совместного использования
            SharedGraphicsDeviceManager.Current.GraphicsDevice.SetSharingMode(true);

            // Создание нового SpriteBatch, который может использоваться для рисования текстур.
            spriteBatch = new SpriteBatch(SharedGraphicsDeviceManager.Current.GraphicsDevice);

            // Загружаем игровой контент
            mySprite = contentManager.Load<Texture2D>("ball");

            // Запуск таймера
            timer.Start();

            base.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            // Остановка таймера
            timer.Stop();

            // В графическом устройстве выключите визуализацию XNA для режима совместного использования
            SharedGraphicsDeviceManager.Current.GraphicsDevice.SetSharingMode(false);

            base.OnNavigatedFrom(e);
        }

        /// <summary>
        /// Позволяет странице выполнять логику, такую как обновление окружения,
        /// поиск конфликтов, сбор входных данных и воспроизведение звука.
        /// </summary>
        private void OnUpdate(object sender, GameTimerEventArgs e)
        {
            //Получаем коллекцию объектов, содержащих информацию о касаниях экрана
            TouchCollection touchLocations = TouchPanel.GetState();
            //Перебираем коллекцию, присваивая объекту координаты касания
            foreach (TouchLocation touchLocation in touchLocations)
            {
                if (touchLocation.State == TouchLocationState.Pressed)
                {
                    position = touchLocation.Position;
                }
            }
        }

        /// <summary>
        /// Разрешает автоматическую прорисовку страницы.
        /// </summary>
        private void OnDraw(object sender, GameTimerEventArgs e)
        {
            // Очищаем экран
            SharedGraphicsDeviceManager.Current.GraphicsDevice.Clear(Color.CornflowerBlue);
            // Выводим изображение
            spriteBatch.Begin();
                spriteBatch.Draw(mySprite, position, Color.White);
            spriteBatch.End();
        }
    }
}